@@ -3,7 +3,7 @@ library(testthat)
 library(magrittr)
 
 context( "inverse by name" )
-  
+test_that( 'inverse', {
 # inverse names
   expect_equal( inverse( as.name('+') ), as.name('-') )
   expect_equal( inverse( as.name('-') ), as.name('+') )
@@ -35,4 +35,4 @@ context('inverse by function definition' )
   inverse( `-` ) %>% expect_identical( `+` )
   inverse( `*` ) %>% expect_identical( `/` )
   inverse( `/` ) %>% expect_identical( `*` )
-  
\ No newline at end of file
+})
\ No newline at end of file
